# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: SignedTimestamp.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='SignedTimestamp.proto',
  package='compubapi_v1',
  syntax='proto3',
  serialized_options=_b('\n$com.yoti.api.client.spi.remote.protoB\024SignedTimestampProtoZ\014yotiprotocom\252\002\031Yoti.Auth.ProtoBuf.Common\312\002\tCompubapi'),
  serialized_pb=_b('\n\x15SignedTimestamp.proto\x12\x0c\x63ompubapi_v1\"\x9b\x01\n\x0fSignedTimestamp\x12\x0f\n\x07version\x18\x01 \x01(\x05\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x16\n\x0emessage_digest\x18\x03 \x01(\x0c\x12\x14\n\x0c\x63hain_digest\x18\x04 \x01(\x0c\x12\x1a\n\x12\x63hain_digest_skip1\x18\x05 \x01(\x0c\x12\x1a\n\x12\x63hain_digest_skip2\x18\x06 \x01(\x0c\x42r\n$com.yoti.api.client.spi.remote.protoB\x14SignedTimestampProtoZ\x0cyotiprotocom\xaa\x02\x19Yoti.Auth.ProtoBuf.Common\xca\x02\tCompubapib\x06proto3')
)




_SIGNEDTIMESTAMP = _descriptor.Descriptor(
  name='SignedTimestamp',
  full_name='compubapi_v1.SignedTimestamp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='compubapi_v1.SignedTimestamp.version', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='compubapi_v1.SignedTimestamp.timestamp', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message_digest', full_name='compubapi_v1.SignedTimestamp.message_digest', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chain_digest', full_name='compubapi_v1.SignedTimestamp.chain_digest', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chain_digest_skip1', full_name='compubapi_v1.SignedTimestamp.chain_digest_skip1', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chain_digest_skip2', full_name='compubapi_v1.SignedTimestamp.chain_digest_skip2', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=40,
  serialized_end=195,
)

DESCRIPTOR.message_types_by_name['SignedTimestamp'] = _SIGNEDTIMESTAMP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SignedTimestamp = _reflection.GeneratedProtocolMessageType('SignedTimestamp', (_message.Message,), dict(
  DESCRIPTOR = _SIGNEDTIMESTAMP,
  __module__ = 'SignedTimestamp_pb2'
  # @@protoc_insertion_point(class_scope:compubapi_v1.SignedTimestamp)
  ))
_sym_db.RegisterMessage(SignedTimestamp)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
