# -*- coding: utf-8 -*-

SDK_IDENTIFIER = "Python"
ATTRIBUTE_AGE_OVER = "age_over:"
ATTRIBUTE_AGE_UNDER = "age_under:"
ATTRIBUTE_DATE_OF_BIRTH = "date_of_birth"
ATTRIBUTE_FAMILY_NAME = "family_name"
ATTRIBUTE_FULL_NAME = "full_name"
ATTRIBUTE_GENDER = "gender"
ATTRIBUTE_GIVEN_NAMES = "given_names"
ATTRIBUTE_NATIONALITY = "nationality"
ATTRIBUTE_EMAIL_ADDRESS = "email_address"
ATTRIBUTE_PHONE_NUMBER = "phone_number"
ATTRIBUTE_POSTAL_ADDRESS = "postal_address"
ATTRIBUTE_SELFIE = "selfie"
ATTRIBUTE_STRUCTURED_POSTAL_ADDRESS = "structured_postal_address"
ATTRIBUTE_DOCUMENT_IMAGES = "document_images"
ATTRIBUTE_DOCUMENT_DETAILS = "document_details"
ATTRIBUTE_APPLICATION_NAME = "application_name"
ATTRIBUTE_APPLICATION_LOGO = "application_logo"
ATTRIBUTE_APPLICATION_URL = "application_url"
ATTRIBUTE_APPLICATION_RECEIPT_BGCOLOR = "application_receipt_bgcolor"
ANCHOR_SOURCE = "SOURCE"
ANCHOR_VERIFIER = "VERIFIER"
KEY_AGE_VERIFIED = "is_age_verified"
KEY_BASE64_SELFIE = "base64_selfie_uri"
KEY_FORMATTED_ADDRESS = "formatted_address"
X_YOTI_AUTH_KEY = "X-Yoti-Auth-Key"
X_YOTI_AUTH_DIGEST = "X-Yoti-Auth-Digest"
X_YOTI_SDK = "X-Yoti-SDK"
X_YOTI_SDK_VERSION = X_YOTI_SDK + "-Version"
JSON_CONTENT_TYPE = "application/json"
