# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: List.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Attribute_pb2 as Attribute__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='List.proto',
  package='attrpubapi_v1',
  syntax='proto3',
  serialized_options=_b('\n$com.yoti.api.client.spi.remote.protoB\022AttributeListProtoZ\ryotiprotoattr\252\002\034Yoti.Auth.ProtoBuf.Attribute\312\002\nAttrpubapi'),
  serialized_pb=_b('\n\nList.proto\x12\rattrpubapi_v1\x1a\x0f\x41ttribute.proto\"S\n\x0e\x41ttributeAndId\x12+\n\tattribute\x18\x01 \x01(\x0b\x32\x18.attrpubapi_v1.Attribute\x12\x14\n\x0c\x61ttribute_id\x18\x02 \x01(\x0c\"R\n\x12\x41ttributeAndIdList\x12<\n\x15\x61ttribute_and_id_list\x18\x01 \x03(\x0b\x32\x1d.attrpubapi_v1.AttributeAndId\"=\n\rAttributeList\x12,\n\nattributes\x18\x01 \x03(\x0b\x32\x18.attrpubapi_v1.AttributeBu\n$com.yoti.api.client.spi.remote.protoB\x12\x41ttributeListProtoZ\ryotiprotoattr\xaa\x02\x1cYoti.Auth.ProtoBuf.Attribute\xca\x02\nAttrpubapib\x06proto3')
  ,
  dependencies=[Attribute__pb2.DESCRIPTOR,])




_ATTRIBUTEANDID = _descriptor.Descriptor(
  name='AttributeAndId',
  full_name='attrpubapi_v1.AttributeAndId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute', full_name='attrpubapi_v1.AttributeAndId.attribute', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute_id', full_name='attrpubapi_v1.AttributeAndId.attribute_id', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46,
  serialized_end=129,
)


_ATTRIBUTEANDIDLIST = _descriptor.Descriptor(
  name='AttributeAndIdList',
  full_name='attrpubapi_v1.AttributeAndIdList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attribute_and_id_list', full_name='attrpubapi_v1.AttributeAndIdList.attribute_and_id_list', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=131,
  serialized_end=213,
)


_ATTRIBUTELIST = _descriptor.Descriptor(
  name='AttributeList',
  full_name='attrpubapi_v1.AttributeList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attributes', full_name='attrpubapi_v1.AttributeList.attributes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=215,
  serialized_end=276,
)

_ATTRIBUTEANDID.fields_by_name['attribute'].message_type = Attribute__pb2._ATTRIBUTE
_ATTRIBUTEANDIDLIST.fields_by_name['attribute_and_id_list'].message_type = _ATTRIBUTEANDID
_ATTRIBUTELIST.fields_by_name['attributes'].message_type = Attribute__pb2._ATTRIBUTE
DESCRIPTOR.message_types_by_name['AttributeAndId'] = _ATTRIBUTEANDID
DESCRIPTOR.message_types_by_name['AttributeAndIdList'] = _ATTRIBUTEANDIDLIST
DESCRIPTOR.message_types_by_name['AttributeList'] = _ATTRIBUTELIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AttributeAndId = _reflection.GeneratedProtocolMessageType('AttributeAndId', (_message.Message,), dict(
  DESCRIPTOR = _ATTRIBUTEANDID,
  __module__ = 'List_pb2'
  # @@protoc_insertion_point(class_scope:attrpubapi_v1.AttributeAndId)
  ))
_sym_db.RegisterMessage(AttributeAndId)

AttributeAndIdList = _reflection.GeneratedProtocolMessageType('AttributeAndIdList', (_message.Message,), dict(
  DESCRIPTOR = _ATTRIBUTEANDIDLIST,
  __module__ = 'List_pb2'
  # @@protoc_insertion_point(class_scope:attrpubapi_v1.AttributeAndIdList)
  ))
_sym_db.RegisterMessage(AttributeAndIdList)

AttributeList = _reflection.GeneratedProtocolMessageType('AttributeList', (_message.Message,), dict(
  DESCRIPTOR = _ATTRIBUTELIST,
  __module__ = 'List_pb2'
  # @@protoc_insertion_point(class_scope:attrpubapi_v1.AttributeList)
  ))
_sym_db.RegisterMessage(AttributeList)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
