# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Signing.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ContentType_pb2 as ContentType__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='Signing.proto',
  package='attrpubapi_v1',
  syntax='proto3',
  serialized_options=_b('\n$com.yoti.api.client.spi.remote.protoB\014SigningProtoZ\ryotiprotoattr\252\002\034Yoti.Auth.ProtoBuf.Attribute\312\002\nAttrpubapi'),
  serialized_pb=_b('\n\rSigning.proto\x12\rattrpubapi_v1\x1a\x11\x43ontentType.proto\"\xaa\x01\n\x10\x41ttributeSigning\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\x12\x30\n\x0c\x63ontent_type\x18\x03 \x01(\x0e\x32\x1a.attrpubapi_v1.ContentType\x12\x1a\n\x12\x61rtifact_signature\x18\x04 \x01(\x0c\x12\x10\n\x08sub_type\x18\x05 \x01(\t\x12\x19\n\x11signed_time_stamp\x18\x06 \x01(\x0c\x42o\n$com.yoti.api.client.spi.remote.protoB\x0cSigningProtoZ\ryotiprotoattr\xaa\x02\x1cYoti.Auth.ProtoBuf.Attribute\xca\x02\nAttrpubapib\x06proto3')
  ,
  dependencies=[ContentType__pb2.DESCRIPTOR,])




_ATTRIBUTESIGNING = _descriptor.Descriptor(
  name='AttributeSigning',
  full_name='attrpubapi_v1.AttributeSigning',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='attrpubapi_v1.AttributeSigning.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='attrpubapi_v1.AttributeSigning.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_type', full_name='attrpubapi_v1.AttributeSigning.content_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='artifact_signature', full_name='attrpubapi_v1.AttributeSigning.artifact_signature', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sub_type', full_name='attrpubapi_v1.AttributeSigning.sub_type', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signed_time_stamp', full_name='attrpubapi_v1.AttributeSigning.signed_time_stamp', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=222,
)

_ATTRIBUTESIGNING.fields_by_name['content_type'].enum_type = ContentType__pb2._CONTENTTYPE
DESCRIPTOR.message_types_by_name['AttributeSigning'] = _ATTRIBUTESIGNING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AttributeSigning = _reflection.GeneratedProtocolMessageType('AttributeSigning', (_message.Message,), dict(
  DESCRIPTOR = _ATTRIBUTESIGNING,
  __module__ = 'Signing_pb2'
  # @@protoc_insertion_point(class_scope:attrpubapi_v1.AttributeSigning)
  ))
_sym_db.RegisterMessage(AttributeSigning)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
