# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: EncryptedData.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='EncryptedData.proto',
  package='compubapi_v1',
  syntax='proto3',
  serialized_options=_b('\n$com.yoti.api.client.spi.remote.protoB\022EncryptedDataProtoZ\014yotiprotocom\252\002\031Yoti.Auth.ProtoBuf.Common\312\002\tCompubapi'),
  serialized_pb=_b('\n\x13\x45ncryptedData.proto\x12\x0c\x63ompubapi_v1\"0\n\rEncryptedData\x12\n\n\x02iv\x18\x01 \x01(\x0c\x12\x13\n\x0b\x63ipher_text\x18\x02 \x01(\x0c\x42p\n$com.yoti.api.client.spi.remote.protoB\x12\x45ncryptedDataProtoZ\x0cyotiprotocom\xaa\x02\x19Yoti.Auth.ProtoBuf.Common\xca\x02\tCompubapib\x06proto3')
)




_ENCRYPTEDDATA = _descriptor.Descriptor(
  name='EncryptedData',
  full_name='compubapi_v1.EncryptedData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='iv', full_name='compubapi_v1.EncryptedData.iv', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cipher_text', full_name='compubapi_v1.EncryptedData.cipher_text', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=37,
  serialized_end=85,
)

DESCRIPTOR.message_types_by_name['EncryptedData'] = _ENCRYPTEDDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EncryptedData = _reflection.GeneratedProtocolMessageType('EncryptedData', (_message.Message,), dict(
  DESCRIPTOR = _ENCRYPTEDDATA,
  __module__ = 'EncryptedData_pb2'
  # @@protoc_insertion_point(class_scope:compubapi_v1.EncryptedData)
  ))
_sym_db.RegisterMessage(EncryptedData)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
