# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ContentType.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ContentType.proto',
  package='attrpubapi_v1',
  syntax='proto3',
  serialized_options=_b('\n$com.yoti.api.client.spi.remote.protoB\020ContentTypeProtoZ\ryotiprotoattr\252\002\034Yoti.Auth.ProtoBuf.Attribute\312\002\nAttrpubapi'),
  serialized_pb=_b('\n\x11\x43ontentType.proto\x12\rattrpubapi_v1*i\n\x0b\x43ontentType\x12\r\n\tUNDEFINED\x10\x00\x12\n\n\x06STRING\x10\x01\x12\x08\n\x04JPEG\x10\x02\x12\x08\n\x04\x44\x41TE\x10\x03\x12\x07\n\x03PNG\x10\x04\x12\x08\n\x04JSON\x10\x05\x12\x0f\n\x0bMULTI_VALUE\x10\x06\x12\x07\n\x03INT\x10\x07\x42s\n$com.yoti.api.client.spi.remote.protoB\x10\x43ontentTypeProtoZ\ryotiprotoattr\xaa\x02\x1cYoti.Auth.ProtoBuf.Attribute\xca\x02\nAttrpubapib\x06proto3')
)

_CONTENTTYPE = _descriptor.EnumDescriptor(
  name='ContentType',
  full_name='attrpubapi_v1.ContentType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNDEFINED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JPEG', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DATE', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PNG', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JSON', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MULTI_VALUE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INT', index=7, number=7,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=36,
  serialized_end=141,
)
_sym_db.RegisterEnumDescriptor(_CONTENTTYPE)

ContentType = enum_type_wrapper.EnumTypeWrapper(_CONTENTTYPE)
UNDEFINED = 0
STRING = 1
JPEG = 2
DATE = 3
PNG = 4
JSON = 5
MULTI_VALUE = 6
INT = 7


DESCRIPTOR.enum_types_by_name['ContentType'] = _CONTENTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
